import { Schema, model, SchemaDefinition } from "mongoose";

import { eloquentSchema } from "./eloquent.schema";

import type { Account } from "@/types/models/account.type";

const schema: SchemaDefinition<Account> = {
  userId: {
    type: String,
    required: true,
    index: { unique: true },
  },
  nickname: {
    type: String,
    required: true,
    default: "nickname",
  },
  avatar: {
    type: String,
    default: "/media/img/no-avatar.png",
  },
  role: {
    type: String,
    default: "user",
  },
  ...eloquentSchema,
};

const schemaSettings = {
  versionKey: false,
  collection: "accounts",
};

const AccountSchema = new Schema<Account>(schema, schemaSettings);

export const AccountModel = model("Account", AccountSchema);
