import { Schema, model, SchemaDefinition } from "mongoose";

import { eloquentSchema } from "./eloquent.schema";

import type { Privilege } from "@/types/models/privilege.type";

const schema: SchemaDefinition<Privilege> = {
  name: {
    type: String,
    required: true,
  },
  privilegeId: {
    type: String,
    required: true,
    index: true,
  },
  amount: {
    type: Number,
    require: false,
    default: 1,
  },
  serviceKey: {
    type: String,
    required: true,
    index: true,
  },
  description: {
    type: String,
    default: "",
  },
  type: {
    type: String,
    required: true,
    default: "count",
  },
  value: {
    type: String,
    required: true,
    default: "1",
  },
  price: {
    type: Number,
    required: false,
  },
  ...eloquentSchema,
};

const schemaSettings = {
  versionKey: false,
  collection: "privilegies",
};

export const PrivilegeSchema = new Schema<Privilege>(schema, schemaSettings);

export const PrivilegeModel = model("Privilege", PrivilegeSchema);
