import { Schema, model, SchemaDefinition } from "mongoose";

import { eloquentSchema } from "./eloquent.schema";
import { PrivilegeSchema } from "./privilege.model";

import type { Tariff } from "@/types/models/tariff.type";

const schema: SchemaDefinition<Tariff> = {
  name: {
    type: String,
    required: true,
  },
  price: {
    type: Number,
    required: false,
  },
  userId: {
    type: String,
    required: true,
  },
  isCustom: {
    type: Boolean,
    default: false,
  },
  privilegies: {
    type: [PrivilegeSchema],
    default: [],
  },
  ...eloquentSchema,
};

const schemaSettings = {
  versionKey: false,
  collection: "tariffs",
};

const TariffSchema = new Schema<Tariff>(schema, schemaSettings);

export const TariffModel = model("Tariff", TariffSchema);
