import { Router } from "@/server/router";

import {
  createAccount,
  getAccountByID,
  getAccount,
  setAccountRole,
  getAccounts,
  deleteAccount,
  deleteAccountById,
  removeAccount,
  removeAccountById,
  restoreAccount,
} from "@/handlers/account";
import { verifyUser } from "@/handlers/auth/middleware";

import {
  createAccountSchema,
  getAccountByIdSchema,
  getAccountSchema,
  setAccountRoleSchema,
  getAccountsSchema,
  removeAccountSchema,
  removeAccountByIdSchema,
  restoreAccountSchema,
  deleteAccountSchema,
  deleteAccountByIdSchema,
} from "@/swagger/account";

export const setAccountRoutes = (router: Router): void => {
  router.get("/pagination", getAccounts, { schema: getAccountsSchema });
  router.get("/:userId", getAccountByID, { schema: getAccountByIdSchema });
  router.get("/", getAccount, { preHandler: [verifyUser], schema: getAccountSchema });

  router.post("/", createAccount, { preHandler: [verifyUser], schema: createAccountSchema });
  router.post("/restore", restoreAccount, { preHandler: [verifyUser], schema: restoreAccountSchema });

  router.patch("/role", setAccountRole, { preHandler: [verifyUser], schema: setAccountRoleSchema });

  router.delete("/", removeAccount, { preHandler: [verifyUser], schema: removeAccountSchema });
  router.delete("/:userId", removeAccountById, {
    preHandler: [verifyUser],
    schema: removeAccountByIdSchema,
  });
  router.delete("/delete", deleteAccount, { preHandler: [verifyUser], schema: deleteAccountSchema });
  router.delete("/delete/:userId", deleteAccountById, {
    preHandler: [verifyUser],
    schema: deleteAccountByIdSchema,
  });
};
