import { Router } from "@/server/router";

import {
  getAllPermissions,
  getPermissionById,
  createPermission,
  updatePermission,
  removePermission,
  restorePermission,
} from "@/handlers/permission";

import {
  getAllPermissionsSchema,
  getPermissionByIdSchema,
  createPermissionSchema,
  removePermissionSchema,
  restorePermissionSchema,
  updatePermissionSchema,
} from "@/swagger/permission";

export const setPermissionRoutes = (router: Router): void => {
  router.get("/all", getAllPermissions, { schema: getAllPermissionsSchema });
  router.get("/:permissionId", getPermissionById, { schema: getPermissionByIdSchema });

  router.post("/", createPermission, { schema: createPermissionSchema });
  router.post("/restore/:permissionId", restorePermission, { schema: restorePermissionSchema });

  router.patch("/:permissionId", updatePermission, { schema: updatePermissionSchema });

  router.delete("/:permissionId", removePermission, { schema: removePermissionSchema });
};
