import { Router } from "@/server/router";

import {
  registerPrivilege,
  getAllPrivilegies,
  getAllPrivilegiesMap,
  getPrivilege,
  getServicePrivilegies,
  replacePrivilege,
  registerPrivilegies,
  removePrivilege,
  replacePrivilegies,
  restorePrivilege,
} from "@/handlers/privilege";

import {
  getPrivilegiesSchema,
  getPrivilegiesMapSchema,
  getPrivilegeSchema,
  getServicePrivilegiesSchema,
  registerPrivilegeSchema,
  registerPrivilegiesSchema,
  replacePrivilegeSchema,
  replacePrivilegiesSchema,
  removePrivilegeSchema,
  restorePrivilegeSchema,
} from "@/swagger/privilege";

export const setPrivilegeRoutes = (router: Router): void => {
  router.get("/", getAllPrivilegies, { schema: getPrivilegiesSchema });
  router.get("/service", getAllPrivilegiesMap, { schema: getPrivilegiesMapSchema });
  router.get("/:privilegeId", getPrivilege, { schema: getPrivilegeSchema });
  router.get("/service/:serviceKey", getServicePrivilegies, { schema: getServicePrivilegiesSchema });
  router.post("/", registerPrivilege, { schema: registerPrivilegeSchema });
  router.post("/many", registerPrivilegies, { schema: registerPrivilegiesSchema });
  router.post("/restore/", restorePrivilege, { schema: restorePrivilegeSchema });
  router.put("/", replacePrivilege, { schema: replacePrivilegeSchema });
  router.put("/many", replacePrivilegies, { schema: replacePrivilegiesSchema });
  router.delete("/", removePrivilege, { schema: removePrivilegeSchema });
};
