import { Router } from "@/server/router";

import {
  getRole,
  getAllRoles,
  createRole,
  deleteRole,
  updateRole,
  replaceRole,
  removeRole,
  restoreRole,
} from "@/handlers/roles";

import {
  getRolesSchema,
  getRoleSchema,
  createRoleSchema,
  restoreRoleSchema,
  updateRoleSchema,
  replaceRoleSchema,
  removeRoleSchema,
  deleteRoleSchema,
} from "@/swagger/role";

export const setRoleRoutes = (router: Router): void => {
  router.get("/", getAllRoles, { schema: getRolesSchema });
  router.get("/:query", getRole, { schema: getRoleSchema });
  router.post("/", createRole, { schema: createRoleSchema });
  router.post("/restore", restoreRole, { schema: restoreRoleSchema });
  router.patch("/:query", updateRole, { schema: updateRoleSchema });
  router.put("/:query", replaceRole, { schema: replaceRoleSchema });
  router.delete("/", removeRole, { schema: removeRoleSchema });
  router.delete("/delete", deleteRole, { schema: deleteRoleSchema });
};
