import { Router } from "@/server/router";

import {
  createTariff,
  replaceTariff,
  getTariff,
  getTariffs,
  removeTariff,
  restoreTariff,
  deleteTariff,
} from "@/handlers/tariff";
import { verifyUser } from "@/handlers/auth/middleware";

import {
  getTariffSchema,
  getTariffsSchema,
  createTariffsSchema,
  replaceTariffsSchema,
  removeTariffsSchema,
  restoreTariffsSchema,
  deleteTariffsSchema,
} from "@/swagger/tariff";

export const setTariffRoutes = (router: Router): void => {
  router.get("/", getTariffs, { preHandler: [verifyUser], schema: getTariffsSchema });
  router.get("/:id", getTariff, { preHandler: [verifyUser], schema: getTariffSchema });
  router.post("/", createTariff, { preHandler: [verifyUser], schema: createTariffsSchema });
  router.post("/restore", restoreTariff, { preHandler: [verifyUser], schema: restoreTariffsSchema });
  router.put("/:id", replaceTariff, { preHandler: [verifyUser], schema: replaceTariffsSchema });
  router.delete("/", removeTariff, { preHandler: [verifyUser], schema: removeTariffsSchema });
  router.delete("/delete", deleteTariff, { preHandler: [verifyUser], schema: deleteTariffsSchema });
};
