import { PermissionModel } from "@/models/permission.model";

import { PERMISSIONS, PERMISSION_LIST } from "@/constants/permissions";

import type { Account } from "@/types/models/account.type";
import type { AccountService } from "./permission.interface";
import type { Permission } from "@/types/models/permission.type";

type PermissionServiceDeps = {
  readonly accountService: AccountService;
};

export class PermissionService {
  private accountService: AccountService;

  constructor(deps: PermissionServiceDeps) {
    this.accountService = deps.accountService;
  }

  public async deleteAccount(account: Account): Promise<boolean> {
    try {
      const role = await this.accountService.determineAccountRole(account);

      if (!role.permissions[PERMISSIONS.deleteAccount]) {
        return false;
      }

      return true;
    } catch {
      return false;
    }
  }

  public async getAllPermissions(): Promise<Permission[]> {
    const permissions = await PermissionModel.find({}).lean();

    return [...permissions, ...PERMISSION_LIST];
  }
}
