import type { SwaggerMessage } from "@/types/swagger.type";

export const account: SwaggerMessage = {
  description: "Аккаунт",
  type: "object",
  properties: {
    _id: { type: "string" },
    userId: { type: "string" },
    nickname: { type: "string" },
    avatar: { type: "string" },
    role: { type: "string" },
    isDeleted: { type: "boolean" },
    createdAt: {
      type: "string",
      format: "date-time",
    },
    updatedAt: {
      type: "string",
      format: "date-time",
    },
    deletedAt: {
      type: "string",
      format: "date-time",
    },
  },
  examples: [
    {
      _id: "807f1f77bcf81cd799439011",
      userId: "507f1f77bcf86cd799439011",
      nickname: "Ivanov Ivan Ivanovich",
      avatar: "/media/avatar/default-avatar.jpg",
      role: "user",
      isDeleted: false,
      createdAt: "2017-07-21T17:32:28Z",
      updatedAt: "2017-07-21T17:32:28Z",
    },
    {
      _id: "807f1f77bcf81cd799439011",
      userId: "507f1f77bcf86cd799439011",
      nickname: "Ivanov Ivan Ivanovich",
      avatar: "/media/avatar/default-avatar.jpg",
      role: "user",
      isDeleted: true,
      createdAt: "2017-07-21T17:32:28Z",
      updatedAt: "2019-04-14T15:32:15Z",
      deletedAt: "2021-08-17T13:23:44Z",
    },
  ],
};

export const accounts: SwaggerMessage = {
  description: "Список аккаунтов",
  type: "object",
  properties: {
    accounts: {
      type: "array",
      description: "Массив аккаунтов",
      items: account,
    },
    totalPages: { type: "number" },
  },
  examples: [
    {
      totalPages: 10,
      accounts: [
        {
          _id: "807f1f77bcf81cd799439011",
          userId: "507f1f77bcf86cd799439011",
          nickname: "Ivanov Ivan Ivanovich",
          avatar: "/media/avatar/default-avatar.jpg",
          role: "user",
          isDeleted: false,
          createdAt: "2017-07-21T17:32:28Z",
          updatedAt: "2017-07-21T17:32:28Z",
        },
        {
          _id: "807f1f77bcf81cd799439011",
          userId: "507f1f77bcf86cd799439011",
          nickname: "Ivanov Ivan Ivanovich",
          avatar: "/media/avatar/default-avatar.jpg",
          role: "user",
          isDeleted: true,
          createdAt: "2017-07-21T17:32:28Z",
          updatedAt: "2019-04-14T15:32:15Z",
          deletedAt: "2021-08-17T13:23:44Z",
        },
      ],
    },
  ],
};
