import { getPermissionParams, createPermissionBody } from "./inputs";
import { getPermissionResponse, getAllPermissionsResponse, createPermissionResponse } from "./responses";

import type { SwaggerSchema } from "@/types/swagger.type";

export const getAllPermissionsSchema: SwaggerSchema = {
  summary: "Получение информации об разрешениях",
  description: "Получение списка всех разрешений из БД",
  tags: ["permission"],
  response: getAllPermissionsResponse,
};

export const getPermissionByIdSchema: SwaggerSchema = {
  summary: "Получение информации об аккаунте",
  description: "Получение аккаунта по ID",
  tags: ["permission"],
  params: getPermissionParams,
  response: getPermissionResponse,
};

export const createPermissionSchema: SwaggerSchema = {
  summary: "Создание разрешения",
  tags: ["permission"],
  body: createPermissionBody,
  response: createPermissionResponse,
};

export const removePermissionSchema: SwaggerSchema = {
  summary: "Удаление разрешения",
  description: "Помечает разрешение удалённым, но не удаляет его из БД",
  tags: ["permission"],
  params: getPermissionParams,
  response: getPermissionResponse,
};

export const restorePermissionSchema: SwaggerSchema = {
  summary: "Восстановление разрешения",
  description: "Восстанавливает разрешение, которое не было удалёно окончательно",
  tags: ["permission"],
  params: getPermissionParams,
  response: getPermissionResponse,
};

export const updatePermissionSchema: SwaggerSchema = {
  summary: "Обновление разрешения",
  description: "Обновляет данные о разрешении",
  tags: ["permission"],
  params: getPermissionParams,
  body: createPermissionBody,
  response: getPermissionResponse,
};
