import { privilegeBody, registerPrivilegiesBody, getPrivilegeParams, getServicePrivilegiesParams } from "./inputs";
import {
  getPrivilegeReponse,
  getPrivilegiesReponse,
  getAllPrivilegiesMapReponse,
  getAllPrivilegiesReponse,
  registerPrivilegeResponse,
  replacePrivilegeResponse,
  registerPrivilegiesResponse,
  replacePrivilegiesResponse,
  removePrivilegeResponse,
} from "./responses";

import type { SwaggerSchema } from "@/types/swagger.type";

export const getPrivilegiesSchema: SwaggerSchema = {
  summary: "Получение всех привелегий",
  description: "Получение всех привелегий в виде массива",
  tags: ["privilege"],
  response: getAllPrivilegiesReponse,
};

export const getPrivilegiesMapSchema: SwaggerSchema = {
  summary: "Получение всех привелегий",
  description: "Получение всех привелегий в виде объекта ключ-значение, где ключём является serviceKey",
  tags: ["privilege"],
  response: getAllPrivilegiesMapReponse,
};

export const getPrivilegeSchema: SwaggerSchema = {
  summary: "Получение привилегии по ID",
  tags: ["privilege"],
  params: getPrivilegeParams,
  response: getPrivilegeReponse,
};

export const getServicePrivilegiesSchema: SwaggerSchema = {
  summary: "Получение привилегий сервиса",
  tags: ["privilege"],
  params: getServicePrivilegiesParams,
  response: getPrivilegiesReponse,
};

export const registerPrivilegeSchema: SwaggerSchema = {
  summary: "Регистрация привелегии сервиса",
  tags: ["privilege"],
  body: privilegeBody,
  response: registerPrivilegeResponse,
};

export const registerPrivilegiesSchema: SwaggerSchema = {
  summary: "Регистрация привелегий сервиса",
  tags: ["privilege"],
  body: registerPrivilegiesBody,
  response: registerPrivilegiesResponse,
};

export const replacePrivilegeSchema: SwaggerSchema = {
  summary: "Замена привилегии сервиса",
  tags: ["privilege"],
  body: privilegeBody,
  response: replacePrivilegeResponse,
};

export const replacePrivilegiesSchema: SwaggerSchema = {
  summary: "Замена привилегий сервиса",
  tags: ["privilege"],
  body: registerPrivilegiesBody,
  response: replacePrivilegiesResponse,
};

export const removePrivilegeSchema: SwaggerSchema = {
  summary: "Удаление привелегии",
  tags: ["privilege"],
  body: getPrivilegeParams,
  response: removePrivilegeResponse,
};

export const restorePrivilegeSchema: SwaggerSchema = {
  summary: "Восстановление привилегии",
  tags: ["privilege"],
  body: getPrivilegeParams,
  response: removePrivilegeResponse,
};
