import type { SwaggerMessage } from "@/types/swagger.type";

export const privilegeBody: SwaggerMessage = {
  type: "object",
  required: ["name", "privilegeId", "serviceKey", "description", "type", "value", "amount"],
  properties: {
    name: { type: "string" },
    privilegeId: { type: "string" },
    serviceKey: { type: "string" },
    description: { type: "string" },
    type: { type: "string" },
    value: { type: "string" },
    price: { type: "number" },
    amount: { type: "number" },
  },
  examples: [
    {
      name: "Количество попыток использования",
      privilegeId: "507f1f77bcf86cd799439011",
      serviceKey: "docx-templater-service",
      description: "Количество попыток использования",
      type: "count",
      value: "200",
      price: 12300,
      amount: 300,
    },
  ],
};

export const privilegiesBody: SwaggerMessage = {
  type: "array",
  items: privilegeBody,
};

export const registerPrivilegiesBody: SwaggerMessage = {
  type: "object",
  properties: {
    privilegies: privilegiesBody,
  },
};

export const getPrivilegeParams: SwaggerMessage = {
  type: "object",
  required: ["privilegeId"],
  properties: {
    privilegeId: {
      type: "string",
      description: "ID привилегии (privilegeId)",
    },
  },
  examples: [{ privilegeId: "507f1f77bcf86cd799439011" }],
};

export const getServicePrivilegiesParams: SwaggerMessage = {
  type: "object",
  required: ["serviceKey"],
  properties: {
    serviceKey: {
      type: "string",
      description: "Ключ сервиса",
    },
  },
  examples: [{ serviceKey: "docx-templater-service" }],
};
