import { swaggerError } from "@/utils/swagger-error";

import { privilege } from "./models";

import type { SwaggerMessage } from "@/types/swagger.type";

export const getAllPrivilegiesReponse: Record<string, SwaggerMessage> = {
  200: {
    type: "array",
    description: "Привилегии",
    items: privilege,
  },
};

export const getAllPrivilegiesMapReponse: Record<string, SwaggerMessage> = {
  200: {
    type: "object",
    description: "Привилегии",
    properties: {
      additionalProperties: {
        type: "array",
        description: "Привилегии",
        items: privilege,
      },
    },
    additionalProperties: true,
    example: {
      "docx-templater-service": [
        {
          _id: "63a7b01f1f4117cf861d6d1e",
          name: "Количество попыток использования",
          privilegeId: "507f1f77bcf86cd799439011",
          serviceKey: "docx-templater-service",
          description: "Количество попыток использования",
          type: "count",
          value: "200",
          price: 12300,
          updatedAt: "2022-12-25T02:47:52.405Z",
          isDeleted: false,
          createdAt: "2022-12-25T02:47:52.406Z",
        },
      ],
    },
  },
};

export const getPrivilegiesReponse: Record<string, SwaggerMessage> = {
  200: {
    type: "array",
    description: "Массив привилегий",
    items: privilege,
  },
};

export const getPrivilegeReponse: Record<string, SwaggerMessage> = {
  200: privilege,
  400: swaggerError(400, "invalid id"),
  404: swaggerError(404, "privilege not found"),
};

export const registerPrivilegeResponse: Record<string, SwaggerMessage> = {
  200: privilege,
  400: swaggerError(400, "price must be a number"),
  409: swaggerError(409, "privilege already exist"),
};

export const registerPrivilegiesResponse: Record<string, SwaggerMessage> = {
  200: {
    type: "array",
    description: "Массив привилегий",
    items: privilege,
  },
  400: swaggerError(400, "price must be a number"),
};

export const replacePrivilegeResponse: Record<string, SwaggerMessage> = {
  200: privilege,
  400: swaggerError(400, "invalid 'type' value"),
  404: swaggerError(404, "privilege not found"),
};

export const replacePrivilegiesResponse: Record<string, SwaggerMessage> = {
  200: {
    type: "array",
    description: "Массив привилегий",
    items: privilege,
  },
  400: swaggerError(400, "invalid 'type' value"),
};

export const removePrivilegeResponse: Record<string, SwaggerMessage> = {
  200: privilege,
  400: swaggerError(400, "invalid id"),
  404: swaggerError(404, "privilege not found"),
};
