import { getRoleParams, roleBody, getRoleByIdBody, updateRoleBody } from "./inputs";
import {
  getRolesReponse,
  getRoleReponse,
  createRoleReponse,
  restoreRoleReponse,
  updateRoleReponse,
  removeRoleReponse,
} from "./responses";

import type { SwaggerSchema } from "@/types/swagger.type";

export const getRolesSchema: SwaggerSchema = {
  summary: "Получение всех ролей",
  tags: ["role"],
  response: getRolesReponse,
};

export const getRoleSchema: SwaggerSchema = {
  summary: "Получение роли",
  tags: ["role"],
  params: getRoleParams,
  response: getRoleReponse,
};

export const createRoleSchema: SwaggerSchema = {
  summary: "Создание роли",
  tags: ["role"],
  body: roleBody,
  response: createRoleReponse,
};

export const restoreRoleSchema: SwaggerSchema = {
  summary: "Восстановление удалённой роли",
  description: "Восстанавливает удалённую роль, которая ещё существует в БД",
  tags: ["role"],
  body: getRoleByIdBody,
  response: restoreRoleReponse,
};

export const updateRoleSchema: SwaggerSchema = {
  summary: "Обновление роли",
  tags: ["role"],
  params: getRoleParams,
  body: updateRoleBody,
  response: updateRoleReponse,
};

export const replaceRoleSchema: SwaggerSchema = {
  summary: "Замена роли",
  tags: ["role"],
  params: getRoleParams,
  body: roleBody,
  response: updateRoleReponse,
};

export const removeRoleSchema: SwaggerSchema = {
  summary: "Удаление роли",
  description: "Помечает роль удалённой, но не удаляет её окончательно",
  tags: ["role"],
  body: getRoleByIdBody,
  response: removeRoleReponse,
};

export const deleteRoleSchema: SwaggerSchema = {
  summary: "Получение всех ролей",
  description: "Удаляет роль окончательно",
  tags: ["role"],
  body: getRoleByIdBody,
  response: getRolesReponse,
};
