import { getTariffParams, tariffBody, replaceTariffParams, getTariffsQuerystring } from "./inputs";
import {
  getTariffReponse,
  getTariffsReponse,
  createTariffReponse,
  replaceTariffReponse,
  removeTariffReponse,
} from "./responses";

import type { SwaggerSchema } from "@/types/swagger.type";

export const getTariffSchema: SwaggerSchema = {
  summary: "Получение тарифа",
  tags: ["tariff"],
  params: getTariffParams,
  response: getTariffReponse,
};

export const getTariffsSchema: SwaggerSchema = {
  summary: "Получение списка тарифов",
  tags: ["tariff"],
  querystring: getTariffsQuerystring,
  response: getTariffsReponse,
};

export const createTariffsSchema: SwaggerSchema = {
  summary: "Создание тарифа",
  tags: ["tariff"],
  body: tariffBody,
  security: [{ bearer: [] }],
  response: createTariffReponse,
};

export const replaceTariffsSchema: SwaggerSchema = {
  summary: "Замена тарифа",
  tags: ["tariff"],
  params: replaceTariffParams,
  body: tariffBody,
  security: [{ bearer: [] }],
  response: replaceTariffReponse,
};

export const removeTariffsSchema: SwaggerSchema = {
  summary: "Удаление тарифа",
  description: "Помечает тариф удалённым, но не удаляет его из БД",
  tags: ["tariff"],
  body: getTariffParams,
  security: [{ bearer: [] }],
  response: removeTariffReponse,
};

export const deleteTariffsSchema: SwaggerSchema = {
  summary: "Удаление тарифа",
  description: "Удаляет тариф из БД окончательно",
  tags: ["tariff"],
  body: getTariffParams,
  security: [{ bearer: [] }],
  response: removeTariffReponse,
};

export const restoreTariffsSchema: SwaggerSchema = {
  summary: "Восстановление тарифа",
  tags: ["tariff"],
  body: getTariffParams,
  security: [{ bearer: [] }],
  response: removeTariffReponse,
};
