import type { SwaggerMessage } from "@/types/swagger.type";

export const getTariffParams: SwaggerMessage = {
  type: "object",
  required: ["id"],
  properties: {
    id: {
      type: "string",
      description: "ID тарифа",
    },
  },
  examples: [{ id: "507f1f77bcf86cd799439011" }],
};

export const getTariffsQuerystring: SwaggerMessage = {
  type: "object",
  properties: {
    page: {
      type: "number",
      description: "номер страницы",
    },
    limit: {
      type: "number",
      description: "Лимит количества аккаунтов (больше 100 не обрабатывается)",
    },
  },
};

export const tariffBody: SwaggerMessage = {
  type: "object",
  description: "Тариф",
  required: ["name", "isCustom", "privilegies"],
  properties: {
    name: { type: "string" },
    price: { type: "number" },
    isCustom: { type: "boolean" },
    privilegies: {
      type: "array",
      items: {
        type: "object",
        description: "Привилегия",
        properties: {
          name: { type: "string" },
          privilegeId: { type: "string" },
          serviceKey: { type: "string" },
          description: { type: "string" },
          amount: { type: "number" },
          type: { type: "string" },
          value: { type: "string" },
          price: { type: "number" },
        },
      },
    },
  },
  examples: [
    {
      name: "Использование сервисов",
      price: 14000,
      isCustom: false,
      privilegies: [
        {
          name: "Количество попыток использования",
          privilegeId: "507f1f77bcf86cd799439011",
          serviceKey: "docx-templater-service",
          description: "Количество попыток использования",
          type: "count",
          value: "200",
          price: 12300,
          amount: 300,
        },
      ],
    },
  ],
};

export const replaceTariffParams: SwaggerMessage = {
  type: "object",
  required: ["id"],
  properties: {
    id: {
      type: "string",
      description: "ID тарифа",
    },
  },
  examples: [{ id: "63a7d47ba24613f98562bafa" }],
};
