import type { ObjectWithRequiredFields } from "@/types/object-with-required-fields";

type KeyValue = Record<string, unknown>;
type Keys<T> = Array<keyof T>;
type ValidateEmptyFields<T extends KeyValue> = [ObjectWithRequiredFields<T>, Error | null];

export const validateEmptyFields = <T extends KeyValue>(
  record: T,
  keys: Keys<T> = [],
  strict = true
): ValidateEmptyFields<T> => {
  const validatedRecord = record as ObjectWithRequiredFields<T>;

  for (const key of keys) {
    if (strict && !record[key]) {
      return [validatedRecord, new Error(`field <${key as string}> is empty`)];
    }
    if (!strict && (record[key] === undefined || record[key] === null)) {
      return [validatedRecord, new Error(`field <${key as string}> is empty`)];
    }
  }

  return [validatedRecord, null];
};
